Module printer

Module printer 

Provides a way to print various types of data to a printer device.

Structs

DxgiPrintContext
Represents a print context during printing via DXGI.
ImagePrinter
A printer that prints images. Multiple frames in a single image file will be printed as separate pages.
PdfiumPrinter
A printer that uses Pdfium to print PDF documents.
PrinterDevice
Represents a printer device.
WinPdfPrinter
A printer that uses Windows.Data.Pdf to to print PDF documents.
XpsPrinter
A printer to print XPS documents.

Enums

DxgiPrintContextError
Represents an error occurred while printing via DXGI.
ImagePrinterError
Represents an error from ImagePrinter.
PdfiumPrinterError
Represents an error from PdfiumPrinter.
WinPdfPrinterError
Represents an error from WinPdfPrinter.
XpsPrinterError
Represents an error from XpsPrinter.

Traits

FilePrinter
A trait representing a printer that can print files.