DxgiPrintContext

Struct DxgiPrintContext 

pub struct DxgiPrintContext {
    pub d3d_device: ID3D11Device,
    pub d3d_context: ID3D11DeviceContext,
    pub dxgi_device: IDXGIDevice,
    pub d2d_factory: ID2D1Factory1,
    pub d2d_device: ID2D1Device,
    pub d2d_context: ID2D1DeviceContext,
    pub wic_factory: IWICImagingFactory2,
    pub document_target_factory: IPrintDocumentPackageTargetFactory,
    pub document_target: IPrintDocumentPackageTarget,
    pub print_control: ID2D1PrintControl,
    pub completion_waiter: PrintCompletionWaiter,
    /* private fields */
}
Represents a print context during printing via DXGI.

Fields

d3d_device: ID3D11Deviced3d_context: ID3D11DeviceContextdxgi_device: IDXGIDeviced2d_factory: ID2D1Factory1d2d_device: ID2D1Deviced2d_context: ID2D1DeviceContextwic_factory: IWICImagingFactory2document_target_factory: IPrintDocumentPackageTargetFactorydocument_target: IPrintDocumentPackageTargetprint_control: ID2D1PrintControlcompletion_waiter: PrintCompletionWaiter

Implementations

Source

impl DxgiPrintContext

pub fn new( device: &PrinterDevice, options: &PrintTicket, job_name: &OsStr, ) -> Result<Self, DxgiPrintContextError>

Create a new print context, used for printing via DXGI.

pub fn close_and_wait(self) -> Result<(), DxgiPrintContextError>

Close the print context and wait for the completion of the print job.