pub struct ImagePrinter { /* private fields */ }Expand description
A printer that prints images. Multiple frames in a single image file will be printed as separate pages.
Implementations
Sourceimpl ImagePrinter
impl ImagePrinter
Sourcepub fn new(printer: PrinterDevice) -> Self
pub fn new(printer: PrinterDevice) -> Self
Create a new ImagePrinter for the given printer device.
Sourcepub fn print_with_options(
&self,
path: &Path,
options: PrintTicket,
auto_rotate: bool,
) -> Result<(), ImagePrinterError>
pub fn print_with_options( &self, path: &Path, options: PrintTicket, auto_rotate: bool, ) -> Result<(), ImagePrinterError>
Print an image with additional options.
When auto_rotate is true, the image will be automatically rotated 90°
to best fit the paper orientation (only when the image and paper aspect
ratios mismatch). This is useful when no explicit orientation parameter
is provided by the caller.