pub fn thread_local() -> PrinterDeviceExpand description
Get a thread-local null printer device. This device is automatically managed and to be deleted when the thread ends.
pub fn thread_local() -> PrinterDeviceGet a thread-local null printer device. This device is automatically managed and to be deleted when the thread ends.