pub struct ScoredProperty {
pub name: Option<OwnedName>,
pub parameter_ref: Option<OwnedName>,
pub value: Option<PropertyValue>,
pub scored_properties: Vec<ScoredProperty>,
pub properties: Vec<Property>,
}Expand description
Represents a scored-property.
A ScoredProperty declares a property that is intrinsic to an Option.
Such properties should be compared when evaluating how closely a requested Option matches a device-supported Option.
Fields
name: Option<OwnedName>The name of the scored-property.
parameter_ref: Option<OwnedName>The parameter that this scored-property depends on.
value: Option<PropertyValue>The value of the scored-property.
scored_properties: Vec<ScoredProperty>Sub-scored-properties of the scored-property
properties: Vec<Property>Properties of the scored-property
Implementations
Sourceimpl ScoredProperty
impl ScoredProperty
Sourcepub fn parameters_dependent(&self) -> Vec<OwnedName>
pub fn parameters_dependent(&self) -> Vec<OwnedName>
Collect all parameters that this scored-property depends on.
Sourcepub fn value_with<'a>(
&'a self,
parameters: &'a [ParameterInit],
) -> Option<&'a PropertyValue>
pub fn value_with<'a>( &'a self, parameters: &'a [ParameterInit], ) -> Option<&'a PropertyValue>
Get the value of this scored-property, or the value of the parameter it references.