pub enum PredefinedDuplexType {
OneSided,
TwoSidedShortEdge,
TwoSidedLongEdge,
}Expand description
Represents a predefined duplex type.
Variants
OneSided
One sided printing
TwoSidedShortEdge
Two sided printing such that the page is flipped parallel to the width direction
TwoSidedLongEdge
Two sided printing such that the page is flipped parallel to the height direction