PrintCapabilities

Struct PrintCapabilities 

pub struct PrintCapabilities {
    pub document: PrintCapabilitiesDocument,
}
Represents print capabilities.

Fields

document: PrintCapabilitiesDocument

DOM of print capabilities document.

Implementations

Source

impl PrintCapabilities

pub fn fetch_xml( device: &PrinterDevice, ) -> Result<Vec<u8>, FetchPrintCapabilitiesError>

Fetch print capabilities XML (without parsing it) for the given printer device.

pub fn fetch_xml_for_ticket( device: &PrinterDevice, ticket: Option<&PrintTicket>, ) -> Result<Vec<u8>, FetchPrintCapabilitiesError>

Fetch print capabilities XML (without parsing it) for the given printer device and print ticket.

pub fn fetch( device: &PrinterDevice, ) -> Result<PrintCapabilities, FetchPrintCapabilitiesError>

Fetch and parse print capabilities for the given printer device.

pub fn default_parameters(&self) -> impl Iterator<Item = ParameterInit> + '_

Defines all parameters with default values.

pub fn default_parameters_for<'a>( &'a self, filters: &'a [OwnedName], ) -> impl Iterator<Item = ParameterInit> + 'a

Defines the given parameters with default values.

pub fn options_for_feature( &self, feature_name: OwnedName, ) -> impl Iterator<Item = &PrintFeatureOption> + '_

Get all options for the given feature.

pub fn page_media_sizes(&self) -> impl Iterator<Item = PageMediaSize> + '_

Get all page media sizes.

pub fn page_orientations(&self) -> impl Iterator<Item = PageOrientation> + '_

Get all supported page orientations.

pub fn duplexes(&self) -> impl Iterator<Item = JobDuplex> + '_

Get all supported job duplex types.

Note

This corresponds to the Print Schema’s JobDuplexAllDocumentsContiguously keyword, not the DocumentDuplex keyword.

pub fn page_output_colors(&self) -> impl Iterator<Item = PageOutputColor> + '_

Get all supported page output colors.

pub fn page_resolutions(&self) -> impl Iterator<Item = PageResolution> + '_

Get all supported page resolutions.

pub fn max_copies(&self) -> Option<Copies>

Get the maximum number of copies that a printer can print. Return None if the device does not report a maximum.

Note

This corresponds to the Print Schema’s JobCopiesAllDocuments keyword, not the DocumentCopiesAllPages keyword, or the PageCopies keyword. If the printer can print unlimited copies, the property value is 9999.