FeatureOptionPackWithPredefined

Trait FeatureOptionPackWithPredefined 

pub trait FeatureOptionPackWithPredefined: FeatureOptionPack {
    type PredefinedName: PredefinedName;

    // Provided method
    fn as_predefined_name(&self) -> Option<Self::PredefinedName> { ... }
}
A trait for the feature option pack with predefined name.

Required Associated Types

type PredefinedName: PredefinedName

The type which represents the predefined name.

Provided Methods

fn as_predefined_name(&self) -> Option<Self::PredefinedName>

Get the predefined name of the option. If the option is not predefined, None is returned.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors