Provides a way to print various types of data to a printer device.
Structs
- Dxgi
Print Context - Represents a print context during printing via DXGI.
- Image
Printer - A printer that prints images. Multiple frames in a single image file will be printed as separate pages.
- Pdfium
Printer - A printer that uses Pdfium to print PDF documents.
- Printer
Device - Represents a printer device.
- WinPdf
Printer - A printer that uses
Windows.Data.Pdfto to print PDF documents. - XpsPrinter
- A printer to print XPS documents.
Enums
- Dxgi
Print Context Error - Represents an error occurred while printing via DXGI.
- Image
Printer Error - Represents an error from
ImagePrinter. - Pdfium
Printer Error - Represents an error from
PdfiumPrinter. - WinPdf
Printer Error - Represents an error from
WinPdfPrinter. - XpsPrinter
Error - Represents an error from
XpsPrinter.
Traits
- File
Printer - A trait representing a printer that can print files.