FeatureOptionPack

Trait FeatureOptionPack 

pub trait FeatureOptionPack: Sized {
    // Required methods
    fn new(option: PrintFeatureOption, parameters: Vec<ParameterInit>) -> Self;
    fn feature_name() -> OwnedName;
    fn option(&self) -> &PrintFeatureOption;
    fn option_mut(&mut self) -> &mut PrintFeatureOption;
    fn parameters(&self) -> &[ParameterInit];
    fn parameters_mut(&mut self) -> &mut Vec<ParameterInit>;
    fn into_option_with_parameters(
        self,
    ) -> (PrintFeatureOption, Vec<ParameterInit>);

    // Provided methods
    fn display_name(&self) -> Option<&str> { ... }
    fn list(capabilities: &PrintCapabilities) -> impl Iterator<Item = Self> + '_ { ... }
}
A trait for the feature option pack.

Required Methods

fn new(option: PrintFeatureOption, parameters: Vec<ParameterInit>) -> Self

Create a new instance.

fn feature_name() -> OwnedName

Get the feature name of the option.

fn option(&self) -> &PrintFeatureOption

Get the DOM of the option.

fn option_mut(&mut self) -> &mut PrintFeatureOption

Get the mutable reference to the DOM of the option.

fn parameters(&self) -> &[ParameterInit]

Get the parameters that is used by the option.

fn parameters_mut(&mut self) -> &mut Vec<ParameterInit>

Get the mutable reference to the parameters that is used by the option.

fn into_option_with_parameters(self) -> (PrintFeatureOption, Vec<ParameterInit>)

Convert the feature option pack into the option and the parameters.

Provided Methods

fn display_name(&self) -> Option<&str>

Get display name of the page orientation.

fn list(capabilities: &PrintCapabilities) -> impl Iterator<Item = Self> + '_

List all possible options defined in the capabilities.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors