pub trait FeatureOptionPackWithPredefined: FeatureOptionPack {
type PredefinedName: PredefinedName;
// Provided method
fn as_predefined_name(&self) -> Option<Self::PredefinedName> { ... }
}Expand description
A trait for the feature option pack with predefined name.
Required Associated Types
Sourcetype PredefinedName: PredefinedName
type PredefinedName: PredefinedName
The type which represents the predefined name.
Provided Methods
Sourcefn as_predefined_name(&self) -> Option<Self::PredefinedName>
fn as_predefined_name(&self) -> Option<Self::PredefinedName>
Get the predefined name of the option.
If the option is not predefined, None is returned.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".